# Ebook Extractor

Export ebooks from any platform as PDF files or images.

![poster](docs/_static/poster.png)

## Installation

```shell
pip install "ebook-extractor[app]"
```

## Usage

### Script

```shell
ebook-extractor
```

### Module

```shell
python -m ebook_extractor
```

### Build

```shell
pyinstaller -F -w -n EbookExtractor ebook_extractor_cli/__main__.py
```

## FAQ

### macOS Hotkeys are not Working

System Settings -> Privacy & Security -> Accessibility